@@ -54,7 +54,7 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
      load(comdataname)
      comdata<-edit(comdata)
      comdata<- na.omit(comdata)
-     colnames(comdata)<-list("subj","time","conc","drug")
+     colnames(comdata)<-list("subj","time","conc","conc_data","drug")
      cat("\n\n")
      
        description_drug()
@@ -64,8 +64,8 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
        cat("\n\n")
        
        Tcomdata<-split(comdata, list(comdata$drug))     
-       ref_data<-data.frame(subj=Tcomdata[[1]]$subj,time=Tcomdata[[1]]$time,conc=Tcomdata[[1]]$conc) 
-       test_data<-data.frame(subj=Tcomdata[[2]]$subj,time=Tcomdata[[2]]$time,conc=Tcomdata[[2]]$conc)
+       ref_data<-data.frame(subj=Tcomdata[[1]]$subj,time=Tcomdata[[1]]$time,conc=Tcomdata[[1]]$conc,conc_data=Tcomdata[[1]]$conc_data) 
+       test_data<-data.frame(subj=Tcomdata[[2]]$subj,time=Tcomdata[[2]]$time,conc=Tcomdata[[2]]$conc,conc_data=Tcomdata[[2]]$conc_data)
   
        rdata.split<-split(ref_data,list(ref_data$subj))
        tdata.split<-split(test_data,list(test_data$subj))
