@@ -1,5 +1,5 @@
 #choose separator and decimal type
-NCA.BANOVAcsv<-function(replicated=FALSE)
+NCA.BANOVAcsv<-function(replicated=FALSE, parallel=FALSE)
 {
 cat("\n")
 file.menu <- c("separator = comma (,) &  decimal = point (.)",
@@ -19,24 +19,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
-       
+         if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
           if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+          }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+        if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }    
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }
 
  else {
@@ -45,23 +54,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+         }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-           if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+           if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }       
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }
  else {
   if (pick == 3){
@@ -69,23 +88,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+            if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }       
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }
  else {
   if (pick == 4){
@@ -93,23 +122,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+            if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }       
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      } 
  else {
   if (pick == 5){
@@ -117,23 +156,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+           if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }       
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }
  else {
   if (pick == 6){
@@ -141,23 +190,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+            if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }        
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }
  else {
   if (pick == 7){
@@ -165,23 +224,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+            if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }        
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      } 
  else {
   if (pick == 8){
@@ -189,23 +258,33 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+            if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }        
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      } 
  else {
   if (pick == 9){
@@ -213,33 +292,47 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(parallel){
+         cnames<-c("subj","drug","time", "conc")
+         }
+         else{
         if(replicated){
               cnames<-c("subj", "seq", "prd", "drug","time", "conc")
              }
             else{
               cnames<-c("subj", "seq","prd", "time", "conc")
             }    
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
-            if(replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+           if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+        else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
-            else{
-             return(NCA.BANOVAanalyze(TotalSingledata))
-            }    
+           else{
+              return(NCA.BANOVAanalyze(TotalSingledata))
+             }  
+         }
      }                     
  else {
   if (pick == 10){
-      if(replicated){
-             return(RepNCA.MIXmenu())
-             }
-            else{
-             return (NCA.BANOVAmenu())
-                  }    
-     
+          if(parallel){
+            ParaNCA.MIXmenu()
+           }
+           else{  
+             if (replicated){
+                RepNCA.MIXmenu()
+                }
+             else{
+              NCA.BANOVAmenu()
+                }
+               }
             }
           }
          }
