@@ -1,5 +1,5 @@
 #NCA-->GLM
-NCA.BANOVAdata<-function(replicated=FALSE)
+NCA.BANOVAdata<-function(replicated=FALSE, parallel=FALSE)
 {
 cat("\n")
 file.menu <- c("Input/edit data from keyboard",
@@ -12,15 +12,20 @@ cat("\n")
 pick <- menu(file.menu, title = " << NCA--> Statistical analysis >> ")
 if (pick == 1){
 cat("\n")
-     
+    if(parallel){
+    description_ParaNCAinput()
+    TotalSingledata<-data.frame (subj=c(0),drug=c(0),time=c(0), conc=c(0))
+    }
+    else{
      if(replicated){
        description_RepNCAinput()
        TotalSingledata<-data.frame (subj=c(0),seq=c(0),prd=c(0),drug=c(0),time=c(0), conc=c(0))
        }
        else{
         description_NCAinput()
-        TotalSingledata<-data.frame (subj=c(0), seq=c(0),prd=c(0),time=c(0), conc=c(0) )
+        TotalSingledata<-data.frame (subj=c(0), seq=c(0),prd=c(0),time=c(0), conc=c(0))
         }
+     }
      TotalSingledata<-edit(TotalSingledata)
      TotalSingledata<- na.omit(TotalSingledata)
      show(TotalSingledata)
@@ -65,18 +70,26 @@ cat("\n")
         else{
            save(TotalSingledata,file=TotalSinglename)
           }
-        if (replicated){
+        if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+           else{ 
+         if(replicated){
               return(RepNCA.MIXanalyze(TotalSingledata))
              }
            else{
               return(NCA.BANOVAanalyze(TotalSingledata))
              }  
-      }
-    
-
+         }
+       } 
 else {
   if (pick == 2){
       cat("\n")                                          
+     if(parallel){
+     description_ParaNCAcsv
+      return(ParaNCA.MIXcsv())
+     }
+     else{ 
       if (replicated){
         description_RepNCAcsv
         return(RepNCA.MIXcsv())
@@ -86,7 +99,7 @@ else {
         return(NCA.BANOVAcsv())
         }   
       }
-
+     }
 else {
   if (pick == 3){
      cat("\n")
@@ -96,27 +109,41 @@ else {
      load(TotalSinglename)
      TotalSingledata<-edit(TotalSingledata)
      TotalSingledata<- na.omit(TotalSingledata)
-     if (replicated){
+     if(parallel){
+      colnames(TotalSingledata)<-list("subj", "drug","time", "conc")
+     }
+     else{
+        if (replicated){
               colnames(TotalSingledata)<-list("subj", "seq", "prd", "drug","time", "conc")
             }
            else{
               colnames(TotalSingledata)<-list("subj", "seq", "prd", "time", "conc")
             }
+       }
      cat("\n\n")
      show(TotalSingledata)
      save(TotalSingledata,file=TotalSinglename)
      cat("\n\n")
-        if (replicated){
-             return(RepNCA.MIXanalyze(TotalSingledata))
+        if(parallel){
+            return(ParaNCA.MIXanalyze(TotalSingledata))
+           }
+           else{ 
+         if(replicated){
+              return(RepNCA.MIXanalyze(TotalSingledata))
              }
            else{
               return(NCA.BANOVAanalyze(TotalSingledata))
-             }
+             }  
+         }
       }
 
   else {
   if (pick == 4){
      cat("\n\n")
+     if(parallel){
+            ParaNCA.MIXmenu()
+           }
+           else{  
       if (replicated){
               RepNCA.MIXmenu()
              }
@@ -124,6 +151,7 @@ else {
               NCA.BANOVAmenu()
              }
           }
+        }  
   else {
   if (pick == 5){
       cat("\nThank you for using bear!  Bye now. \n\n")
