@@ -1088,10 +1088,10 @@ cat("\n")
 cat("-------------------------------------------------------------------------\n")
 cat("Both F values and P values were obtained from ANOVA,respectively.\n")
 cat("CI90: 90% confidence interval \n")
-cat("Please note: no posterior power calculated. Ref.: Hoenig JM and Heisey DM. The abuse\n")
-cat("of power: the pervasive fallacy of power calculations for data analysis. The American\n")
-cat("Statistician 55/1, 19-24 (2001). Also the discussions at Bebac Forum --> \n")
-cat("http://forum.bebac.at for more info.\n")
+cat("Please note: no posterior power calculated. Ref.: Hoenig JM and Heisey DM. \n")
+cat("The abuse of power: the pervasive fallacy of power calculations for data \n")
+cat("analysis. The American Statistician 55/1, 19-24 (2001). Also the discussions \n")
+cat("at Bebac Forum --> http://forum.bebac.at for more info.\n")
 cat("--------------------------------------------------------------------------\n")
 #cat("Power: required to detect at least (1-Power) of differences (%).\n")
   }
