@@ -1,5 +1,5 @@
 NCAselectsave.BANOVA<-function(Totalplot, Dose, ref_data, test_data, SingleRdata,SingleRdata1,SingleTdata,SingleTdata1,
 xaxis, yaxis,rdata.split,tdata.split){
 NCAselectsave(Totalplot, Dose, ref_data, test_data, SingleRdata,SingleRdata1,SingleTdata,SingleTdata1,xaxis, yaxis
-            ,rdata.split,tdata.split,BANOVA=TRUE)
+            ,rdata.split,tdata.split,BANOVA=TRUE, replicated=FALSE, MIX=FALSE)
 }
\ No newline at end of file
