@@ -1,5 +1,5 @@
 # List
-RepNCA.MIXmenu<-function()
+RepNCA.MIXmenu<-function(parallel=FALSE)
 {
 cat("\n")
   file.menu <- c("NCA --> Statistical analysis (lme, 90%CI...)",
@@ -7,16 +7,31 @@ cat("\n")
                  "Back to the previous step",
                  "Quit")
  cat("\n")
+  if(parallel){
+  pick <- menu(file.menu, title = " << NCA--> Statistical analysis for Parallel Study>> ")
+   }
+  else{
   pick <- menu(file.menu, title = " << NCA--> Statistical analysis for Replicated Crossover Study>> ")
+  }  
     if (pick == 1){
       cat("\n")
+          if(parallel){
+        ParaNCA.MIXdata()  
+          }
+          else{
         RepNCA.MIXdata()
-        }
+            }
+       } 
     else {
     if (pick == 2){
         cat("\n")
+         if(parallel){
+       Parademomenu1()   
+          }
+          else{
        Repdemomenu1()
-       }
+          }
+      } 
     else {
     if (pick == 3){
         cat("\n")
