@@ -1,5 +1,5 @@
 
 TTTARSdemo<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1){
 TTTARS(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-    Demo=TRUE, BANOVA=FALSE)
+    Demo=TRUE, BANOVA=FALSE,replicated=FALSE)
 }
\ No newline at end of file
