@@ -1,4 +1,4 @@
 TTTdemo<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1){
 TTT(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-   Demo=TRUE, BANOVA=FALSE)
+   Demo=TRUE, BANOVA=FALSE, replicated=FALSE)
 }
\ No newline at end of file
